import yaml

class Prompt:
    """
    A class representing a prompt.

    Args:
        name (str): The name of the prompt.
        description (str): A brief description of the prompt.
        template (str): The template string for the prompt.
    """

    def __init__(self, name, description, template):
        """
        Initialize a new Prompt instance.

        Args:
            name (str): The name of the prompt.
            description (str): A brief description of the prompt.
            template (str): The template string for the prompt.
        """
        self.name = name
        self.description = description
        self.template = template

    def format(self, **kwargs):
        """
        Format the prompt template with the provided keyword arguments.

        Args:
            **kwargs: Keyword arguments to be used for formatting the template.

        Returns:
            str: The formatted prompt string.
        """
        return self.template.format(**kwargs)

    def __str__(self):
        """
        Return a string representation of the Prompt instance.

        Returns:
            str: The string representation of the Prompt instance.
        """
        return f"{self.name}: {self.description}"

    def to_dict(self):
        """
        Convert the Prompt instance to a dictionary.

        Returns:
            dict: A dictionary representation of the Prompt instance.
        """
        return {
            'name': self.name,
            'description': self.description,
            'template': self.template
        }

    @classmethod
    def from_dict(cls, data):
        """
        Create a Prompt instance from a dictionary.

        Args:
            data (dict): A dictionary containing the prompt data.

        Returns:
            Prompt: A new Prompt instance created from the dictionary.
        """
        return cls(data['name'], data['description'], data['template'])

    def save(self, manager):
        """
        Save the Prompt instance using the provided PromptManager.

        Args:
            manager (PromptManager): The PromptManager instance to use for saving the prompt.
        """
        manager.save(self.to_dict(), self.name)

    @classmethod
    def load(cls, manager, name):
        """
        Load a Prompt instance using the provided PromptManager and prompt name.

        Args:
            manager (PromptManager): The PromptManager instance to use for loading the prompt.
            name (str): The name of the prompt to load.

        Returns:
            Prompt: The loaded Prompt instance.
        """
        data = manager.load(name)
        return cls.from_dict(data)


import os
import pytest
from promptsy.prompt_manager import PromptManager

@pytest.fixture
def prompt_manager():
    return PromptManager(base_directory='test_prompts')

def test_prompt_manager_initialization(prompt_manager):
    assert prompt_manager.base_directory == 'test_prompts'
    assert os.path.exists('test_prompts')

def test_get_file_path(prompt_manager):
    file_path = prompt_manager._get_file_path('custom_prompt')
    assert file_path == os.path.join('test_prompts', 'custom', 'custom_prompt.yaml')

    file_path = prompt_manager._get_file_path('examples.hello_world')
    assert file_path == os.path.join('test_prompts', 'examples', 'hello_world.yaml')

def test_save_prompt(prompt_manager):
    prompt_manager.save({'text': 'Hello, {name}!'}, 'custom_prompt')
    file_path = os.path.join('test_prompts', 'custom', 'custom_prompt.yaml')
    assert os.path.exists(file_path)

    with open(file_path, 'r') as file:
        content = file.read()
        assert 'text: Hello, {name}!' in content

def test_load_prompt(prompt_manager):
    prompt_manager.save({'text': 'Hello, {name}!'}, 'custom_prompt')
    loaded_prompt = prompt_manager.load('custom_prompt')
    assert loaded_prompt == {'text': 'Hello, {name}!'}

def test_load_non_existent_prompt(prompt_manager):
    with pytest.raises(FileNotFoundError):
        prompt_manager.load('non_existent_prompt')

def test_list_prompts(prompt_manager):
    prompt_manager.save({'text': 'Hello, {name}!'}, 'examples.hello_world')
    prompt_manager.save({'text': 'Goodbye, {name}!'}, 'examples.goodbye')
    prompt_manager.save({'text': 'Custom prompt'}, 'custom_prompt')

    prompts = prompt_manager.list_prompts()
    assert 'examples.hello_world' in prompts
    assert 'examples.goodbye' in prompts
    assert 'custom.custom_prompt' in prompts



import pytest
from promptsy.prompt import Prompt
from unittest import mock

def test_prompt_initialization():
    prompt = Prompt(
        name="test_prompt",
        description="A test prompt",
        template="Hello, {name}!"
    )
    assert prompt.name == "test_prompt"
    assert prompt.description == "A test prompt"
    assert prompt.template == "Hello, {name}!"

def test_prompt_format():
    prompt = Prompt(
        name="test_prompt",
        description="A test prompt",
        template="Hello, {name}!"
    )
    formatted_prompt = prompt.format(name="John")
    assert formatted_prompt == "Hello, John!"

def test_prompt_str_representation():
    prompt = Prompt(
        name="test_prompt",
        description="A test prompt",
        template="Hello, {name}!"
    )
    assert str(prompt) == "test_prompt: A test prompt"

def test_prompt_to_dict():
    prompt = Prompt(
        name="test_prompt",
        description="A test prompt",
        template="Hello, {name}!"
    )
    prompt_dict = prompt.to_dict()
    assert prompt_dict == {
        'name': 'test_prompt',
        'description': 'A test prompt',
        'template': 'Hello, {name}!'
    }

def test_prompt_from_dict():
    prompt_dict = {
        'name': 'test_prompt',
        'description': 'A test prompt',
        'template': 'Hello, {name}!'
    }
    prompt = Prompt.from_dict(prompt_dict)
    assert prompt.name == "test_prompt"
    assert prompt.description == "A test prompt"
    assert prompt.template == "Hello, {name}!"

def test_prompt_save_and_load():
    manager_mock = mock.Mock()
    prompt = Prompt(
        name="test_prompt",
        description="A test prompt",
        template="Hello, {name}!"
    )
    prompt.save(manager_mock)
    manager_mock.save.assert_called_once_with(prompt.to_dict(), prompt.name)

    manager_mock.load.return_value = prompt.to_dict()
    loaded_prompt = Prompt.load(manager_mock, "test_prompt")
    assert loaded_prompt.name == prompt.name
    assert loaded_prompt.description == prompt.description
    assert loaded_prompt.template == prompt.template



import os
import yaml
from colorama import init, Fore, Style

init()  # Initialize colorama

class PromptManager:
    """
    A class for managing prompts stored in YAML files.

    Args:
        base_directory (str): The base directory where the prompts will be stored. Defaults to 'prompts'.
    """

    def __init__(self, base_directory='prompts'):
        """
        Initialize the PromptManager with the specified base directory.

        Args:
            base_directory (str): The base directory where the prompts will be stored. Defaults to 'prompts'.
        """
        self.base_directory = base_directory
        os.makedirs(base_directory, exist_ok=True)

    def _get_file_path(self, name):
        """
        Get the file path for a prompt with the given name.

        Args:
            name (str): The name of the prompt.

        Returns:
            str: The file path for the prompt.
        """
        parts = name.split('.')
        if len(parts) < 2:
            directory_path = os.path.join(self.base_directory, 'custom')
            file_name = f"{name}.yaml"
        else:
            directory_path = os.path.join(self.base_directory, *parts[:-1])
            file_name = f"{parts[-1]}.yaml"
        
        return os.path.join(directory_path, file_name)

    def save(self, prompt, name):
        """
        Save a prompt to a YAML file.

        Args:
            prompt (dict): The prompt data to be saved.
            name (str): The name of the prompt.
        """
        file_path = self._get_file_path(name)
        os.makedirs(os.path.dirname(file_path), exist_ok=True)
        
        with open(file_path, 'w') as file:
            yaml.dump({'text': prompt}, file)
        print(f"Prompt saved to {file_path}")

    def load(self, name):
        """
        Load a prompt from a YAML file.

        Args:
            name (str): The name of the prompt.

        Returns:
            dict: The loaded prompt data.

        Raises:
            FileNotFoundError: If the prompt file does not exist.
        """
        file_path = self._get_file_path(name)
        
        if not os.path.exists(file_path):
            error_message = f"Prompt file {file_path} does not exist."
            print(Fore.RED + error_message + Style.RESET_ALL)
            raise FileNotFoundError(error_message)
        
        with open(file_path, 'r') as file:
            data = yaml.safe_load(file)
        return data.get('text', '')

    def list_prompts(self):
        """
        List all the available prompts.

        Returns:
            list: A list of prompt names.
        """
        prompts = []
        for root, _, files in os.walk(self.base_directory):
            for file in files:
                if file.endswith('.yaml'):
                    relative_path = os.path.relpath(os.path.join(root, file), self.base_directory)
                    prompts.append(relative_path.replace(os.path.sep, '.').replace('.yaml', ''))
        return prompts


from setuptools import setup, find_packages

setup(
    name='promptsy',
    version='0.1.3',
    description='A Python library for managing and organizing prompts for Large Language Models (LLMs)',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    author='Felipe Rafael de Souza',
    author_email='felipe@evakub.com.br',
    url='https://github.com/feliperafael/promptsy',
    packages=find_packages(),
    install_requires=[
        'PyYAML',
        'colorama',
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    keywords='prompts llm-prompts prompt-management large-language-models',
)